"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _cssToReactNative = _interopRequireDefault(require("css-to-react-native"));
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _useSyntaxHighlighter = require("../../hooks/useSyntaxHighlighter");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable no-console */

const monospaceFont = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
function transformThemeToStyles(theme) {
  const background = theme.colors?.['editor.background'] || '#1e1e1e';
  const foreground = theme.colors?.['editor.foreground'] || '#d4d4d4';
  const styles = _reactNative.StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%',
      backgroundColor: background
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap',
      backgroundColor: background
    },
    token: {
      color: foreground,
      fontFamily: monospaceFont,
      backgroundColor: background
    }
  });
  const tokenStyles = {};
  theme.tokenColors?.forEach(token => {
    if (!token.settings) return;
    const style = (0, _cssToReactNative.default)([['color', token.settings.foreground || foreground], ['backgroundColor', background], ['fontStyle', token.settings.fontStyle || 'normal']]);
    if (token.scope) {
      const scopes = Array.isArray(token.scope) ? token.scope : [token.scope];
      scopes.forEach(scope => {
        tokenStyles[scope] = style;
      });
    }
  });
  return {
    base: styles,
    tokens: tokenStyles
  };
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = (0, _useSyntaxHighlighter.useSyntaxHighlighter)({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const styles = (0, _react.useMemo)(() => transformThemeToStyles(theme), [theme]);
  const cleanStyle = style => {
    const filtered = Object.entries(style).filter(([_key, value]) => value != null).map(([key, value]) => [key, value]);
    console.log('Cleaning style:', style, 'Filtered:', filtered);
    return (0, _cssToReactNative.default)(filtered);
  };
  const renderToken = (token, rowIndex, tokenIndex) => {
    const style = cleanStyle({
      color: token.color,
      fontStyle: token.fontStyle ? 'italic' : 'normal',
      fontWeight: token.fontStyle ? 'bold' : 'normal',
      backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e'
    });
    console.log('Token Style:', {
      input: {
        color: token.color,
        fontStyle: token.fontStyle,
        background: theme.colors?.['editor.background']
      },
      output: style
    });
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: [styles.base.token, style, {
        fontSize
      }, textStyle],
      children: token.content
    }, `${rowIndex}-${tokenIndex}`);
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.base.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.base.codeContainer, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.base.lineContainer,
        children: line.map((token, tokenIndex) => renderToken(token, rowIndex, tokenIndex))
      }, rowIndex))
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map