"use strict";

/* eslint-disable no-console */

import transform from 'css-to-react-native';
import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
function transformThemeToStyles(theme) {
  const background = theme.colors?.['editor.background'] || '#1e1e1e';
  const foreground = theme.colors?.['editor.foreground'] || '#d4d4d4';
  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%',
      backgroundColor: background
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap',
      backgroundColor: background
    },
    token: {
      color: foreground,
      fontFamily: monospaceFont,
      backgroundColor: background
    }
  });
  const tokenStyles = {};
  theme.tokenColors?.forEach(token => {
    if (!token.settings) return;
    const style = transform([['color', token.settings.foreground || foreground], ['backgroundColor', background], ['fontStyle', token.settings.fontStyle || 'normal']]);
    if (token.scope) {
      const scopes = Array.isArray(token.scope) ? token.scope : [token.scope];
      scopes.forEach(scope => {
        tokenStyles[scope] = style;
      });
    }
  });
  return {
    base: styles,
    tokens: tokenStyles
  };
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const styles = useMemo(() => transformThemeToStyles(theme), [theme]);
  const cleanStyle = style => {
    const filtered = Object.entries(style).filter(([_key, value]) => value != null).map(([key, value]) => [key, value]);
    console.log('Cleaning style:', style, 'Filtered:', filtered);
    return transform(filtered);
  };
  const renderToken = (token, rowIndex, tokenIndex) => {
    const style = cleanStyle({
      color: token.color,
      fontStyle: token.fontStyle ? 'italic' : 'normal',
      fontWeight: token.fontStyle ? 'bold' : 'normal',
      backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e'
    });
    console.log('Token Style:', {
      input: {
        color: token.color,
        fontStyle: token.fontStyle,
        background: theme.colors?.['editor.background']
      },
      output: style
    });
    return /*#__PURE__*/_jsx(Text, {
      style: [styles.base.token, style, {
        fontSize
      }, textStyle],
      children: token.content
    }, `${rowIndex}-${tokenIndex}`);
  };
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.base.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.base.codeContainer, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: styles.base.lineContainer,
        children: line.map((token, tokenIndex) => renderToken(token, rowIndex, tokenIndex))
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map